summaryrefslogtreecommitdiff
path: root/framework/source/jobs/jobexecutor.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/jobs/jobexecutor.cxx')
-rw-r--r--framework/source/jobs/jobexecutor.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/source/jobs/jobexecutor.cxx b/framework/source/jobs/jobexecutor.cxx
index 1c3ee7471e79..e4dfbb06138c 100644
--- a/framework/source/jobs/jobexecutor.cxx
+++ b/framework/source/jobs/jobexecutor.cxx
@@ -192,7 +192,7 @@ void JobExecutor::disposing() {
/**
@short implementation of XJobExecutor interface
@descr We use the given event to locate any registered job inside our configuration
- and execute it. Further we control the lifetime of it and supress
+ and execute it. Further we control the lifetime of it and suppress
shutdown of the office till all jobs was finished.
@param sEvent
@@ -209,7 +209,7 @@ void SAL_CALL JobExecutor::trigger( const OUString& sEvent ) throw(css::uno::Run
// Optimization!
// Check if the given event name exist inside configuration and reject wrong requests.
// This optimization supress using of the cfg api for getting event and job descriptions ...
if (m_lEvents.find(sEvent) == m_lEvents.end())
return;
@@ -262,7 +262,7 @@ void SAL_CALL JobExecutor::notifyEvent( const css::document::EventObject& aEvent
// Optimization!
// Check if the given event name exist inside configuration and reject wrong requests.
// This optimization supress using of the cfg api for getting event and job descriptions.
// see using of m_lEvents.find() below ...
// retrieve event context from event source
@@ -209,7 +209,7 @@ void SAL_CALL JobExecutor::trigger( const OUString& sEvent ) throw(css::uno::Run
// Optimization!
// Check if the given event name exist inside configuration and reject wrong requests.
- // This optimization supress using of the cfg api for getting event and job descriptions ...
+ // This optimization suppress using of the cfg api for getting event and job descriptions ...
if (m_lEvents.find(sEvent) == m_lEvents.end())
return;
@@ -262,7 +262,7 @@ void SAL_CALL JobExecutor::notifyEvent( const css::document::EventObject& aEvent
// Optimization!
// Check if the given event name exist inside configuration and reject wrong requests.
- // This optimization supress using of the cfg api for getting event and job descriptions.
+ // This optimization suppress using of the cfg api for getting event and job descriptions.
// see using of m_lEvents.find() below ...
// retrieve event context from event source